{% extends "base.html" %}

{% block base_content %}
    <div id="floater">
        <h1 id="centered">&lt;{{ SITE.name }}/&gt;</h1>
        
        <p>{% trans %}Hello World!{% endtrans %}</p>
    </div>
{% endblock %}
