{% extends "base.html" %}

{% block base_content %}
    <div id="floater">
        <h1 id="centered">&lt;{{ SITE.name }}/&gt;</h1>
        
        <ul>
            <li><a href="sample_default.html">Default language</a></li>
            <li><a href="sample_fr_FR.html">In French</a></li>
            <li><a href="sample_zh_ZH.html">Localized to Chinese but fallback on default lang</a></li>
        </ul>
    </div>
{% endblock %}
